@@ -71,23 +71,26 @@ extern QTime debugSpeedTimer;
 
 const QDBusArgument & operator<<(QDBusArgument &arg, const Property &change)
 {
-        arg.beginStructure();
-        arg << change.name << change.added << change.removed;
-        arg.endStructure();
-        return arg;
+    arg.beginStructure();
+    arg << change.name << change.added << change.removed;
+    arg.endStructure();
+    return arg;
 }
 const QDBusArgument & operator>>(const QDBusArgument &arg, Property &change)
 {
-        arg.beginStructure();
-        arg >> change.name >> change.added >> change.removed;
-        arg.endStructure();
-        return arg;
+    arg.beginStructure();
+    arg >> change.name >> change.added >> change.removed;
+    arg.endStructure();
+    return arg;
 }
 
 MaemoBarcodeWindow::MaemoBarcodeWindow(QWidget *parent)
     : QMainWindow(parent)
 {
-    qDebug() << "MainWindow::MainWindow(): Started MaemoBarcodeWindow";
+    // makes sure we don't try to do anything with a pointer to nowhere (using null-checks)
+    videoWidget = NULL;
+
+    qDebug() << DEBUGINFO << "Started MaemoBarcodeWindow";
 
     recentDialog = NULL;
     pluginsLoaded = false;
@@ -95,45 +98,42 @@ MaemoBarcodeWindow::MaemoBarcodeWindow(QWidget *parent)
     imageBuffer = NULL;
 
     // first of all, disable the camera app:
-    qDebug() << "MainWindow::MainWindow(): Killing the camera app, t=" << debugSpeedTimer.elapsed();
+    qDebug() << DEBUGINFO << "Killing the camera app, t=" << debugSpeedTimer.elapsed();
     QProcess process;
     process.execute("/usr/sbin/dsmetool -k /usr/bin/camera-ui");
 
-    qDebug() << "MainWindow::MainWindow(): Setting window title, t=" << debugSpeedTimer.elapsed();
+    qDebug() << DEBUGINFO << "Setting window title, t=" << debugSpeedTimer.elapsed();
     setWindowTitle("Maemo Barcode Reader");
 
     // set up dbus
-    qDebug() << "MainWindow::MainWindow(): Setting up dbus, t=" << debugSpeedTimer.elapsed();
+    qDebug() << DEBUGINFO << "Setting up dbus, t=" << debugSpeedTimer.elapsed();
     qDBusRegisterMetaType< Property >();
     qDBusRegisterMetaType< QList<Property> >();
-    qDebug() << "MainWindow::MainWindow(): Setting up lensCoverPropertyModified";
+    qDebug() << DEBUGINFO << "Setting up lensCoverPropertyModified";
     QDBusConnection::systemBus().connect(QString(),
-            DBUS_SHUTTER_STATE,
-            "org.freedesktop.Hal.Device", "PropertyModified",
-            this, SLOT(lensCoverPropertyModified(int, QList<Property>)));
-    qDebug() << "MainWindow::MainWindow(): Setting up focusButtonPropertyModified";
+                                         DBUS_SHUTTER_STATE,
+                                         "org.freedesktop.Hal.Device", "PropertyModified",
+                                         this, SLOT(lensCoverPropertyModified(int, QList<Property>)));
+    qDebug() << DEBUGINFO << "Setting up focusButtonPropertyModified";
     QDBusConnection::systemBus().connect(QString(),
-            DBUS_FOCUS_BUTTON,
-            "org.freedesktop.Hal.Device", "PropertyModified",
-            this, SLOT(focusButtonPropertyModified(int, QList<Property>)));
-    qDebug() << "MainWindow::MainWindow(): Setting up cameraButtonPropertyModified";
+                                         DBUS_FOCUS_BUTTON,
+                                         "org.freedesktop.Hal.Device", "PropertyModified",
+                                         this, SLOT(focusButtonPropertyModified(int, QList<Property>)));
+    qDebug() << DEBUGINFO << "Setting up cameraButtonPropertyModified";
     QDBusConnection::systemBus().connect(QString(),
-            DBUS_RELEASE_BUTTON,
-            "org.freedesktop.Hal.Device", "PropertyModified",
-            this, SLOT(cameraButtonPropertyModified(int,QList<Property>)));
+                                         DBUS_RELEASE_BUTTON,
+                                         "org.freedesktop.Hal.Device", "PropertyModified",
+                                         this, SLOT(cameraButtonPropertyModified(int,QList<Property>)));
 
     // init the state of the lens cover
-    qDebug() << "MainWindow::MainWindow(): Initing state of lens cover, t=" << debugSpeedTimer.elapsed();
+    qDebug() << DEBUGINFO << "Initing state of lens cover, t=" << debugSpeedTimer.elapsed();
     initLensCoverState();
 
     // make sure the events are not called to pause the pipeline unecessary in the beginning
     firstChangeEvent = true;
     secondChangeEvent = true;
 
-    // makes sure we don't try to do anything with a pointer to nowhere (using null-checks)
-    videoWidget = NULL;
-
-    qDebug() << "MainWindow::MainWindow(): Creating settings, t=" << debugSpeedTimer.elapsed();
+    qDebug() << DEBUGINFO << "Creating settings, t=" << debugSpeedTimer.elapsed();
     settings = new QSettings("mbarcode", "mbarcode"); // load settings
     if(settings->value("settings_version", 1).toInt() < SETTINGS_VERSION) {
         settings->clear();
@@ -142,37 +142,34 @@ MaemoBarcodeWindow::MaemoBarcodeWindow(QWidget *parent)
 
     this->AutoUseFirstPlugin = settings->value("auto_use_first_plugin", false).toBool();
 
-    qDebug() << "MainWindow::MainWindow(): Initializing decoder, t=" << debugSpeedTimer.elapsed();
+    qDebug() << DEBUGINFO << "Initializing decoder, t=" << debugSpeedTimer.elapsed();
     decoder = new BarcodeDetector(); // create a decoder
 
-    //qDebug() << "MainWindow::MainWindow(): Initializing results window, t=" << debugSpeedTimer.elapsed();
-    //resultsWindow = new ResultsWindow(this); // create a resultswindow
-
     // set up the videoWidget
-    qDebug() << "MainWindow::MainWindow(): Initializing video widget, t=" << debugSpeedTimer.elapsed();
+    qDebug() << DEBUGINFO << "Initializing video widget, t=" << debugSpeedTimer.elapsed();
     videoWidget = new VideoWidget(this, decoder);
-    qDebug() << "MainWindow::MainWindow(): Setting video widget attributes, t=" << debugSpeedTimer.elapsed();
+    qDebug() << DEBUGINFO << "Setting video widget attributes, t=" << debugSpeedTimer.elapsed();
     videoWidget->setAttribute(Qt::WA_NativeWindow, true);
     videoWidget->setContinuousFocusTime((int)(settings->value("autofocus_delay",2.0).toFloat()*1000)); // pull from the settings
-    qDebug() << "MainWindow::MainWindow(): Finished setting video widget attributes, t=" << debugSpeedTimer.elapsed();
+    qDebug() << DEBUGINFO << "Finished setting video widget attributes, t=" << debugSpeedTimer.elapsed();
     //    videoWidget->setMinimumSize(300, 200);
 
     ////videoWidget->setMinimumSize(640,400);
 
     // connect the signal from the barcode decoder
-    qDebug() << "MainWindow::MainWindow(): Connecting signals, t=" << debugSpeedTimer.elapsed();
+    qDebug() << DEBUGINFO << "Connecting signals, t=" << debugSpeedTimer.elapsed();
     connect(decoder, SIGNAL(imageAnalysed(QString, QString, QImage*)),
             this, SLOT(imageAnalysed(QString, QString, QImage*)));
     // connect signals to disable/enable the refocus button
     connect(videoWidget, SIGNAL(focusingValueChanged(bool)), this, SLOT(setFocusing(bool)));
     connect(videoWidget, SIGNAL(doSaveBuffer()), this, SLOT(saveBufferImage()));
 
-    qDebug() << "MainWindow::MainWindow(): Initializing buttons, t=" << debugSpeedTimer.elapsed();
+    qDebug() << DEBUGINFO << "Initializing buttons, t=" << debugSpeedTimer.elapsed();
     setAttribute(Qt::WA_Maemo5StackedWindow);
     setAttribute(Qt::WA_Maemo5AutoOrientation, true); // currently not working since libqt4-maemo5 is broken. Will work in PR1.2
 
     // if the lens cover is open, start scanning
-    qDebug() << "MainWindow::MainWindow(): Checking lens cover state, t=" << debugSpeedTimer.elapsed();
+    qDebug() << DEBUGINFO << "Checking lens cover state, t=" << debugSpeedTimer.elapsed();
     if (isLensCoverOpen()) {
         videoWidget->start(true); // start and keep running
     } else {
@@ -180,14 +177,14 @@ MaemoBarcodeWindow::MaemoBarcodeWindow(QWidget *parent)
         // wait until the lens cover is opened.
     }
 
-    qDebug() << "MainWindow::MainWindow(): Setting central widget, t=" << debugSpeedTimer.elapsed();
+    qDebug() << DEBUGINFO << "Setting central widget, t=" << debugSpeedTimer.elapsed();
     this->setCentralWidget(videoWidget);
     //qDebug() << "MainWindow::MainWindow(): starting pluginloader thread, t=" << debugSpeedTimer.elapsed();
 
     //pluginloaderthread = new PluginLoaderThread(this);
     //pluginloaderthread->start(QThread::LowPriority);
 
-    qDebug() << "MainWindow::MainWindow(): Finished, t=" << debugSpeedTimer.elapsed();
+    qDebug() << DEBUGINFO << "Finished, t=" << debugSpeedTimer.elapsed();
 
     //QTimer::singleShot(2000, this, SLOT(loadPlugins())); // set 2s as a start delay time
 }
@@ -227,9 +224,9 @@ void MaemoBarcodeWindow::lensCoverPropertyModified(int num_updates, QList<Proper
     Q_UNUSED(num_updates)
     Q_UNUSED(updates)
     QDBusInterface propertyInterface("org.freedesktop.Hal",
-                DBUS_SHUTTER_STATE,
-                "org.freedesktop.Hal.Device",
-                QDBusConnection::systemBus());
+                                     DBUS_SHUTTER_STATE,
+                                     "org.freedesktop.Hal.Device",
+                                     QDBusConnection::systemBus());
     lensCoverOpen = !propertyInterface.call("GetProperty", "button.state.value").arguments().at(0).toBool();
     qDebug() << "MaemoBarcodeWindow::lensCoverPropertyModified(): is" << lensCoverOpen;
     if(lensCoverOpen && isActiveWindow()) {
@@ -244,9 +241,9 @@ void MaemoBarcodeWindow::focusButtonPropertyModified(int num_updates, QList<Prop
     Q_UNUSED(num_updates)
     Q_UNUSED(updates)
     QDBusInterface propertyInterface("org.freedesktop.Hal",
-                DBUS_FOCUS_BUTTON,
-                "org.freedesktop.Hal.Device",
-                QDBusConnection::systemBus());
+                                     DBUS_FOCUS_BUTTON,
+                                     "org.freedesktop.Hal.Device",
+                                     QDBusConnection::systemBus());
     bool buttonPressed = propertyInterface.call("GetProperty", "button.state.value").arguments().at(0).toBool();
     qDebug() << "MaemoBarcodeWindow::focusButtonPropertyModified(): is" << buttonPressed;
     if(buttonPressed) {
@@ -258,11 +255,11 @@ void MaemoBarcodeWindow::cameraButtonPropertyModified(int num_updates, QList<Pro
     Q_UNUSED(num_updates)
     Q_UNUSED(updates)
     QDBusInterface propertyInterface("org.freedesktop.Hal",
-                DBUS_RELEASE_BUTTON,
-                "org.freedesktop.Hal.Device",
-                QDBusConnection::systemBus());
+                                     DBUS_RELEASE_BUTTON,
+                                     "org.freedesktop.Hal.Device",
+                                     QDBusConnection::systemBus());
     bool buttonPressed = propertyInterface.call("GetProperty", "button.state.value").arguments().at(0).toBool();
-    qDebug() << "MaemoBarcodeWindow::cameraButtonPropertyModified(: is" << buttonPressed;
+
     if(this->continuousScanningMode==true){
         if(buttonPressed) {
             saveBufferImage();
@@ -388,15 +385,15 @@ void MaemoBarcodeWindow::loadPlugins() {
             settings->setArrayIndex(i);
 
             origPluginNames.append(settings->value("pluginName").toString());
-//            pri = settings->value("pluginPriority").toInt(); // read the saved priority
+            //            pri = settings->value("pluginPriority").toInt(); // read the saved priority
 
-//            while(origPluginPriorities.contains(pri)) // keep incrementing this value until we find a slot that is unused
-//                pri++;
+            //            while(origPluginPriorities.contains(pri)) // keep incrementing this value until we find a slot that is unused
+            //                pri++;
 
-//            if(pri>max_pri)
-//                max_pri = pri; // save for later when we add new plugins
+            //            if(pri>max_pri)
+            //                max_pri = pri; // save for later when we add new plugins
 
-//            origPluginPriorities.append(pri );
+            //            origPluginPriorities.append(pri );
             origPluginEnabled.append(settings->value("pluginEnabled").toBool());
             //origPluginPresent.append(false); // start with false, then we will look later on
 
@@ -413,48 +410,51 @@ void MaemoBarcodeWindow::loadPlugins() {
 
         QPluginLoader loader(fileName); // create a loader for the shared library
         QObject *plugin = loader.instance();  // load it as a QObject
-        if (plugin) { // if it is a plugin (this fails if virtual functions are not implemented correct)
-            cout << "Loaded successfully: " << fileName.toStdString() << endl;
-
-            pluginFileNames += fileName; // list all our plugin file names
-            PluginInterface* interface = qobject_cast<PluginInterface*>(plugin); // cast it to our kind of interface
-            qDebug() << "Interface name: " << interface->getName();
-
-            pluginInterfaces.append(interface); // add this interface to our list of interfaces
-            interface->initInterface(this); // initialize the plugin
-            foreach(PluginAction* pluginAction, interface->getPluginActions()) { // get the list of sink plugins in the interface
-
-                QString pluginIdentifier(interface->getName() + ": " + pluginAction->getName());
-                // this matches the string shown in the pluginsettings window - see the initialisation fn
-
-                // see if we know about this plugin
-                int ind = origPluginNames.indexOf(pluginIdentifier);
-                if (ind>-1){ // for some reason this is never true
-                    // yes we know about this one
-
-                    //pluginAction->setPriority(origPluginPriorities.value(ind));
-                    pluginAction->setEnabled(origPluginEnabled.value(ind));
-
-                    cout << "loadPlugins(): Found plugin listed in settings " << pluginIdentifier.toStdString() << " " << QString("%1").arg(pluginAction->getEnabled()).toStdString() << endl;
-
-                }else{
-                    // no we don't know about this one
-
-                    //pluginAction->setPriority(++max_pri);
-                    pluginAction->setEnabled(true);
-
-                    //qDebug() << "loadPlugins(): Found plugin not listed in settings " << pluginIdentifier << " " << max_pri << " true";
-                    cout << "loadPlugins(): Found plugin not listed in settings " << pluginIdentifier.toStdString() << " 1" << endl;
-                }
-
-                if (pluginAction->getEnabled())
-                    this->NumEnabledPlugins++;
-
-                pluginActions.append(pluginAction); // add them to our list
-            }
-            qApp->processEvents();
+        if (!plugin) { // if it is a plugin (this fails if virtual functions are not implemented correct)
+            qDebug() << DEBUGINFO << "Could not load: " << fileName << " due to error: " << loader.errorString();
         } else {
-            cout << "loadPlugins(): Could not load: " << fileName.toStdString() << " due to error: " << loader.errorString().toStdString() << endl;
+            qDebug() << DEBUGINFO << "Plugin library loaded successfully.";
+            PluginInterface* interface = qobject_cast<PluginInterface*>(plugin); // cast it to our kind of interface
+            if(!interface) {
+                qWarning() << DEBUGINFO << "Plugin interface cast failed! Probably wrong plugin API version.";
+            } else {
+                pluginFileNames += fileName; // list all our plugin file names
+                qDebug() << "Interface name: " << interface->getName();
+
+                pluginInterfaces.append(interface); // add this interface to our list of interfaces
+                interface->initInterface(this); // initialize the plugin
+                foreach(PluginAction* pluginAction, interface->getPluginActions()) { // get the list of sink plugins in the interface
+
+                    QString pluginIdentifier(interface->getName() + ": " + pluginAction->getName());
+                    // this matches the string shown in the pluginsettings window - see the initialisation fn
+
+                    // see if we know about this plugin
+                    int ind = origPluginNames.indexOf(pluginIdentifier);
+                    if (ind>-1){ // for some reason this is never true
+                        // yes we know about this one
+
+                        //pluginAction->setPriority(origPluginPriorities.value(ind));
+                        pluginAction->setEnabled(origPluginEnabled.value(ind));
+
+                        cout << "loadPlugins(): Found plugin listed in settings " << pluginIdentifier.toStdString() << " " << QString("%1").arg(pluginAction->getEnabled()).toStdString() << endl;
+
+                    }else{
+                        // no we don't know about this one
+
+                        //pluginAction->setPriority(++max_pri);
+                        pluginAction->setEnabled(true);
+
+                        //qDebug() << "loadPlugins(): Found plugin not listed in settings " << pluginIdentifier << " " << max_pri << " true";
+                        cout << "loadPlugins(): Found plugin not listed in settings " << pluginIdentifier.toStdString() << " 1" << endl;
+                    }
+
+                    if (pluginAction->getEnabled())
+                        this->NumEnabledPlugins++;
+
+                    pluginActions.append(pluginAction); // add them to our list
+                }
+                qApp->processEvents();
+            }
         }
     }
 
@@ -489,6 +489,14 @@ void MaemoBarcodeWindow::imageAnalysed(QString barcodeType, QString barcodeData,
     ensurePluginsLoaded();
     emit barcodeAnalysedSignal(barcodeType, barcodeData); // emit a signal for whoever's listening. Especially plugins :)
 
+    // send DBus message
+    QList<QVariant> argList;
+    argList << barcodeType << barcodeData;
+    QDBusMessage message = QDBusMessage::createSignal(QString("org.maemo.mbarcode"), QString("org.maemo.mbarcode"), QString("BarcodeDecoded"));
+    message.setArguments(argList);
+    QDBusConnection::systemBus().send(message);
+
+
     if(this->AutoUseFirstPlugin){
         resultsWindow->processBarcode(barcodeData);
     }else // no point in showing it if we'll soon remove it
@@ -555,8 +563,8 @@ void MaemoBarcodeWindow::OpenAndScanImage()
     if (img.width()>MAX_VIDEO_WIDTH && img.height()>MAX_VIDEO_HEIGHT) // both too big, so see which one we should scale to bring both down to correct size
         if (float(img.width())/float(MAX_VIDEO_WIDTH) > float(img.height())/float(MAX_VIDEO_HEIGHT))
             img = img.scaledToWidth(MAX_VIDEO_WIDTH,Qt::SmoothTransformation);
-        else
-            img = img.scaledToWidth(MAX_VIDEO_HEIGHT,Qt::SmoothTransformation);
+    else
+        img = img.scaledToWidth(MAX_VIDEO_HEIGHT,Qt::SmoothTransformation);
     else if (img.width()>MAX_VIDEO_WIDTH)
         img = img.scaledToWidth(MAX_VIDEO_WIDTH,Qt::SmoothTransformation);
     else if (img.height()>MAX_VIDEO_HEIGHT)
@@ -568,8 +576,8 @@ void MaemoBarcodeWindow::OpenAndScanImage()
 
     char fourcc[5] = "RGB3";
     int bpp = 24;
-//    char fourcc[5] = "Y800";
-//    int bpp = 8;
+    //    char fourcc[5] = "Y800";
+    //    int bpp = 8;
 
 
 
@@ -619,20 +627,20 @@ void MaemoBarcodeWindow::OpenAndScanImage()
         }
     }
 
-//    qDebug() << "Image data w=" << img.width() << "height " << img.height() << "bytes per line " << img.bytesPerLine() << "bytecount " << img.byteCount();
+    //    qDebug() << "Image data w=" << img.width() << "height " << img.height() << "bytes per line " << img.bytesPerLine() << "bytecount " << img.byteCount();
 
-//    // debugging, as we don't seem to be able to decode
-//    QFile file("/home/user/mbarcode-image.raw");
-//    file.open(QIODevice::WriteOnly);
-//    file.write((const char*)(imageBuffer), img.height()*width*bpp/8);
-//    file.close();
+    //    // debugging, as we don't seem to be able to decode
+    //    QFile file("/home/user/mbarcode-image.raw");
+    //    file.open(QIODevice::WriteOnly);
+    //    file.write((const char*)(imageBuffer), img.height()*width*bpp/8);
+    //    file.close();
 
-//    img.save("/home/user/mbarcode-image.png");
+    //    img.save("/home/user/mbarcode-image.png");
 
 
 
     int type = decoder->analyseImageSync((char *)imageBuffer, width, img.height(), fourcc, bpp, 1000, this, SLOT(analyseImageSyncCallBack()));
-
+    Q_UNUSED(type)
     free(imageBuffer);
     imageBuffer=0;
 }
@@ -644,8 +652,6 @@ void MaemoBarcodeWindow::analyseImageSyncCallBack(){
     if(imageBuffer)
         free(imageBuffer);
 
-    qDebug() << "In MaemoBarcodeWindow::analyseImageSyncCallBack()";
-
     if(result)
         QMaemo5InformationBox::information (this, "Barcode detected", 1000);
     else
