@@ -4,17 +4,31 @@
 #include "maemobarcodewindow.h"
 #include "resultswindow.h"
 
-PluginLoaderThread::PluginLoaderThread(MaemoBarcodeWindow *resultsWindow)
+
+extern QTime debugSpeedTimer;
+
+
+PluginLoaderThread::PluginLoaderThread(MaemoBarcodeWindow *mainWindow)
 {
-    this->w = resultsWindow;
+    this->w = mainWindow;
 }
 
 
 void PluginLoaderThread::run()
+{
+    QTimer::singleShot(3000, this, SLOT(loadPlugins())); // set 2s as a start delay time
+    exec();
+}
+
+void PluginLoaderThread::loadPlugins()
 {
     // TODO: Create a system which lets the user enable/disable plugins. These should not be loaded.
 
-    qDebug("Loading plugins...");
+    qDebug() << "PluginLoaderThread::loadPlugins(): Initializing results window, t=" << debugSpeedTimer.elapsed();
+    w->resultsWindow = new ResultsWindow(w); // create a resultswindow
+
+    qDebug() << "Loading plugins..., t=" << debugSpeedTimer.elapsed();
+
 
     //    pluginsDir = QDir(qApp->applicationDirPath());.
     QDir pluginsDir = QDir("/usr/share/mbarcode/");
@@ -63,4 +77,5 @@ void PluginLoaderThread::run()
     w->resultsWindow->setPluginActions(w->pluginActions); // let the resultwindow have all our plugins
     w->pluginsLoaded = true;
 
+    exit();
 }
