@@ -109,7 +109,7 @@ VideoWidget::VideoWidget(MaemoBarcodeWindow *parent, BarcodeDetector *decoder) :
     imgRecent = imgRecent.scaledToWidth(48, Qt::SmoothTransformation);
     imgSettings = QImage(":/images/gui/settings.png");
     imgSettings = imgSettings.scaledToWidth(48, Qt::SmoothTransformation);
-    imgOpen = QImage(":/images/gui/task-manager.png");
+    imgOpen = QImage(":/images/gui/load.png");
     imgOpen = imgOpen.scaledToWidth(48, Qt::SmoothTransformation);
 
     qDebug() << "VideoWidget::VideoWidget(): Setting up frame counts";
