@@ -26,13 +26,13 @@ ZBarDecoderThread::ZBarDecoderThread()
     isDecoding=false;
 
     this->scanner = zbar_image_scanner_create();
-    cout << "Created scanner" << endl;
+    qDebug() << DEBUGINFO << "Created scanner";
     /* configure the reader */
     //zbar_image_scanner_set_config(scanner, NULL, ZBAR_CFG_ENABLE, 1);
     //zbar_image_scanner_enable_cache(this->scanner, TRUE);
-    cout << "Enabled scanner" << endl;
+    qDebug() << DEBUGINFO <<  "Enabled scanner";
     this->image = zbar_image_create();
-    cout << "Created image" << endl;
+    qDebug() << DEBUGINFO << "Created image";
 
 }
 
